import os

TEST_BUCKET = os.getenv("GCSFS_TEST_BUCKET", "gcsfs_test")
TEST_PROJECT = os.getenv("GCSFS_TEST_PROJECT", "project")
TEST_REQUESTER_PAYS_BUCKET = "gcsfs_test_req_pay"
TEST_KMS_KEY = os.getenv(
    "GCSFS_TEST_KMS_KEY",
    f"projects/{TEST_PROJECT}/locations/us/keyRings/gcsfs_test/cryptKeys/gcsfs_test_key",
)



import fsspec
import pytest
from fsspec.tests.abstract import AbstractFixtures

from gcsfs.core import GCSFileSystem
from gcsfs.tests.conftest import allfiles
from gcsfs.tests.settings import TEST_BUCKET


class GcsfsFixtures(AbstractFixtures):
    @pytest.fixture(scope="class")
    def fs(self, docker_gcs):
        GCSFileSystem.clear_instance_cache()
        gcs = fsspec.filesystem("gcs", endpoint_url=docker_gcs)
        try:
            # ensure we're empty.
            try:
                gcs.rm(TEST_BUCKET, recursive=True)
            except FileNotFoundError:
                pass
            try:
                gcs.mkdir(TEST_BUCKET)
            except Exception:
                pass

            gcs.pipe({TEST_BUCKET + "/" + k: v for k, v in allfiles.items()})
            gcs.invalidate_cache()
            yield gcs
        finally:
            try:
                gcs.rm(gcs.find(TEST_BUCKET))
                gcs.rm(TEST_BUCKET)
            except:  # noqa: E722
                pass

    @pytest.fixture
    def fs_path(self):
        return TEST_BUCKET

    @pytest.fixture
    def supports_empty_directories(self):
        return False



import pytest

from gcsfs import GCSFileSystem
from gcsfs.credentials import GoogleCredentials
from gcsfs.retry import HttpError


def test_googlecredentials_none():
    credentials = GoogleCredentials(project="myproject", token=None, access="read_only")
    headers = {}
    credentials.apply(headers)


@pytest.mark.parametrize("token", ["", "incorrect.token", "x" * 100])
def test_credentials_from_raw_token(token):
    with pytest.raises(HttpError, match="Invalid Credentials"):
        fs = GCSFileSystem(project="myproject", token=token)
        fs.ls("/")
